import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource schema for AppSync ChannelNamespace
 */
export declare function getChannelNamespace(args: GetChannelNamespaceArgs, opts?: pulumi.InvokeOptions): Promise<GetChannelNamespaceResult>;
export interface GetChannelNamespaceArgs {
    /**
     * The Amazon Resource Name (ARN) of the channel namespace.
     */
    channelNamespaceArn: string;
}
export interface GetChannelNamespaceResult {
    /**
     * The Amazon Resource Name (ARN) of the channel namespace.
     */
    readonly channelNamespaceArn?: string;
    /**
     * The event handler functions that run custom business logic to process published events and subscribe requests.
     */
    readonly codeHandlers?: string;
    /**
     * List of AuthModes supported for Publish operations.
     */
    readonly publishAuthModes?: outputs.appsync.ChannelNamespaceAuthMode[];
    /**
     * List of AuthModes supported for Subscribe operations.
     */
    readonly subscribeAuthModes?: outputs.appsync.ChannelNamespaceAuthMode[];
    /**
     * A set of tags (key-value pairs) for this channel namespace.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource schema for AppSync ChannelNamespace
 */
export declare function getChannelNamespaceOutput(args: GetChannelNamespaceOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetChannelNamespaceResult>;
export interface GetChannelNamespaceOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the channel namespace.
     */
    channelNamespaceArn: pulumi.Input<string>;
}
