import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Batch::ConsumableResource
 */
export declare class ConsumableResource extends pulumi.CustomResource {
    /**
     * Get an existing ConsumableResource resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ConsumableResource;
    /**
     * Returns true if the given object is an instance of ConsumableResource.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ConsumableResource;
    /**
     * Available Quantity of ConsumableResource.
     */
    readonly availableQuantity: pulumi.Output<number>;
    /**
     * The Amazon Resource Name (ARN) of the consumable resource.
     */
    readonly consumableResourceArn: pulumi.Output<string>;
    /**
     * Name of ConsumableResource.
     */
    readonly consumableResourceName: pulumi.Output<string | undefined>;
    /**
     * The Unix timestamp (in milliseconds) for when the consumable resource was created.
     */
    readonly createdAt: pulumi.Output<number>;
    /**
     * In-use Quantity of ConsumableResource.
     */
    readonly inUseQuantity: pulumi.Output<number>;
    /**
     * Indicates whether the resource is available to be re-used after a job completes. Can be one of:
     *
     * - `REPLENISHABLE`
     * - `NON_REPLENISHABLE`
     */
    readonly resourceType: pulumi.Output<enums.batch.ConsumableResourceResourceType>;
    /**
     * A key-value pair to associate with a resource.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Total Quantity of ConsumableResource.
     */
    readonly totalQuantity: pulumi.Output<number>;
    /**
     * Create a ConsumableResource resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ConsumableResourceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ConsumableResource resource.
 */
export interface ConsumableResourceArgs {
    /**
     * Name of ConsumableResource.
     */
    consumableResourceName?: pulumi.Input<string>;
    /**
     * Indicates whether the resource is available to be re-used after a job completes. Can be one of:
     *
     * - `REPLENISHABLE`
     * - `NON_REPLENISHABLE`
     */
    resourceType: pulumi.Input<enums.batch.ConsumableResourceResourceType>;
    /**
     * A key-value pair to associate with a resource.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * Total Quantity of ConsumableResource.
     */
    totalQuantity: pulumi.Input<number>;
}
