import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Represents a collaboration between AWS accounts that allows for secure data collaboration
 */
export declare function getCollaboration(args: GetCollaborationArgs, opts?: pulumi.InvokeOptions): Promise<GetCollaborationResult>;
export interface GetCollaborationArgs {
    /**
     * Returns the unique identifier of the specified collaboration.
     *
     * Example: `a1b2c3d4-5678-90ab-cdef-EXAMPLE11111`
     */
    collaborationIdentifier: string;
}
export interface GetCollaborationResult {
    /**
     * Returns the Amazon Resource Name (ARN) of the specified collaboration.
     *
     * Example: `arn:aws:cleanrooms:us-east-1:111122223333:collaboration/a1b2c3d4-5678-90ab-cdef-EXAMPLE11111`
     */
    readonly arn?: string;
    /**
     * Returns the unique identifier of the specified collaboration.
     *
     * Example: `a1b2c3d4-5678-90ab-cdef-EXAMPLE11111`
     */
    readonly collaborationIdentifier?: string;
    /**
     * A description of the collaboration provided by the collaboration owner.
     */
    readonly description?: string;
    /**
     * A human-readable identifier provided by the collaboration owner. Display names are not unique.
     */
    readonly name?: string;
    /**
     * An arbitrary set of tags (key-value pairs) for this cleanrooms collaboration.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Represents a collaboration between AWS accounts that allows for secure data collaboration
 */
export declare function getCollaborationOutput(args: GetCollaborationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetCollaborationResult>;
export interface GetCollaborationOutputArgs {
    /**
     * Returns the unique identifier of the specified collaboration.
     *
     * Example: `a1b2c3d4-5678-90ab-cdef-EXAMPLE11111`
     */
    collaborationIdentifier: pulumi.Input<string>;
}
