import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Register as a publisher in the CloudFormation Registry.
 */
export declare function getPublisher(args: GetPublisherArgs, opts?: pulumi.InvokeOptions): Promise<GetPublisherResult>;
export interface GetPublisherArgs {
    /**
     * The reserved publisher id for this type, or the publisher id assigned by CloudFormation for publishing in this region.
     */
    publisherId: string;
}
export interface GetPublisherResult {
    /**
     * The type of account used as the identity provider when registering this publisher with CloudFormation.
     */
    readonly identityProvider?: enums.cloudformation.PublisherIdentityProvider;
    /**
     * The reserved publisher id for this type, or the publisher id assigned by CloudFormation for publishing in this region.
     */
    readonly publisherId?: string;
    /**
     * The URL to the publisher's profile with the identity provider.
     */
    readonly publisherProfile?: string;
    /**
     * Whether the publisher is verified.
     */
    readonly publisherStatus?: enums.cloudformation.PublisherStatus;
}
/**
 * Register as a publisher in the CloudFormation Registry.
 */
export declare function getPublisherOutput(args: GetPublisherOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetPublisherResult>;
export interface GetPublisherOutputArgs {
    /**
     * The reserved publisher id for this type, or the publisher id assigned by CloudFormation for publishing in this region.
     */
    publisherId: pulumi.Input<string>;
}
