import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * A response headers policy.
 *  A response headers policy contains information about a set of HTTP response headers.
 *  After you create a response headers policy, you can use its ID to attach it to one or more cache behaviors in a CloudFront distribution. When it's attached to a cache behavior, the response headers policy affects the HTTP headers that CloudFront includes in HTTP responses to requests that match the cache behavior. CloudFront adds or removes response headers according to the configuration of the response headers policy.
 *  For more information, see [Adding or removing HTTP headers in CloudFront responses](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/modifying-response-headers.html) in the *Amazon CloudFront Developer Guide*.
 */
export declare function getResponseHeadersPolicy(args: GetResponseHeadersPolicyArgs, opts?: pulumi.InvokeOptions): Promise<GetResponseHeadersPolicyResult>;
export interface GetResponseHeadersPolicyArgs {
    /**
     * The unique identifier for the response headers policy. For example: `57f99797-3b20-4e1b-a728-27972a74082a` .
     */
    id: string;
}
export interface GetResponseHeadersPolicyResult {
    /**
     * The unique identifier for the response headers policy. For example: `57f99797-3b20-4e1b-a728-27972a74082a` .
     */
    readonly id?: string;
    /**
     * The date and time when the response headers policy was last modified.
     */
    readonly lastModifiedTime?: string;
    /**
     * A response headers policy configuration.
     */
    readonly responseHeadersPolicyConfig?: outputs.cloudfront.ResponseHeadersPolicyConfig;
}
/**
 * A response headers policy.
 *  A response headers policy contains information about a set of HTTP response headers.
 *  After you create a response headers policy, you can use its ID to attach it to one or more cache behaviors in a CloudFront distribution. When it's attached to a cache behavior, the response headers policy affects the HTTP headers that CloudFront includes in HTTP responses to requests that match the cache behavior. CloudFront adds or removes response headers according to the configuration of the response headers policy.
 *  For more information, see [Adding or removing HTTP headers in CloudFront responses](https://docs.aws.amazon.com/AmazonCloudFront/latest/DeveloperGuide/modifying-response-headers.html) in the *Amazon CloudFront Developer Guide*.
 */
export declare function getResponseHeadersPolicyOutput(args: GetResponseHeadersPolicyOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetResponseHeadersPolicyResult>;
export interface GetResponseHeadersPolicyOutputArgs {
    /**
     * The unique identifier for the response headers policy. For example: `57f99797-3b20-4e1b-a728-27972a74082a` .
     */
    id: pulumi.Input<string>;
}
