import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Cognito::LogDeliveryConfiguration
 */
export declare class LogDeliveryConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing LogDeliveryConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): LogDeliveryConfiguration;
    /**
     * Returns true if the given object is an instance of LogDeliveryConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is LogDeliveryConfiguration;
    /**
     * A user pool ID, for example `us-east-1_EXAMPLE` .
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * A logging destination of a user pool. User pools can have multiple logging destinations for message-delivery and user-activity logs.
     */
    readonly logConfigurations: pulumi.Output<outputs.cognito.LogDeliveryConfigurationLogConfiguration[] | undefined>;
    /**
     * The ID of the user pool where you configured logging.
     */
    readonly userPoolId: pulumi.Output<string>;
    /**
     * Create a LogDeliveryConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: LogDeliveryConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a LogDeliveryConfiguration resource.
 */
export interface LogDeliveryConfigurationArgs {
    /**
     * A logging destination of a user pool. User pools can have multiple logging destinations for message-delivery and user-activity logs.
     */
    logConfigurations?: pulumi.Input<pulumi.Input<inputs.cognito.LogDeliveryConfigurationLogConfigurationArgs>[]>;
    /**
     * The ID of the user pool where you configured logging.
     */
    userPoolId: pulumi.Input<string>;
}
