import * as outputs from "../types/output";
import { Region } from "..";
/**
 * The access key for API operations. You can retrieve this from the ‘Security & Credentials’ section of the AWS console.
 */
export declare const accessKey: string | undefined;
/**
 * List of allowed AWS account IDs to prevent you from mistakenly using an incorrect one. Conflicts with `forbiddenAccountIds`.
 */
export declare const allowedAccountIds: string[] | undefined;
/**
 * Configuration for retrieving temporary credentials from the STS service.
 */
export declare const assumeRole: outputs.config.AssumeRole | undefined;
/**
 * The configuration for automatically naming resources.
 */
export declare const autoNaming: outputs.config.AutoNaming | undefined;
/**
 * Configuration block with resource tag settings to apply across all resources handled by this provider. This is designed to replace redundant per-resource `tags` configurations. Provider tags can be overridden with new values, but not excluded from specific resources. To override provider tag values, use the `tags` argument within a resource to configure new tag values for matching keys.
 */
export declare const defaultTags: outputs.config.DefaultTags | undefined;
/**
 * Configuration block for customizing service endpoints.
 */
export declare const endpoints: outputs.config.Endpoints | undefined;
/**
 * List of forbidden AWS account IDs to prevent you from mistakenly using the wrong one (and potentially end up destroying a live environment). Conflicts with `allowedAccountIds`.
 */
export declare const forbiddenAccountIds: string[] | undefined;
/**
 * Configuration block with resource tag settings to ignore across all resources handled by this provider (except any individual service tag resources such as `ec2.Tag`) for situations where external systems are managing certain resource tags.
 */
export declare const ignoreTags: outputs.config.IgnoreTags | undefined;
/**
 * Explicitly allow the provider to perform "insecure" SSL requests. If omitted,default value is `false`.
 */
export declare const insecure: boolean | undefined;
/**
 * The maximum number of times an AWS API request is being executed. If the API request still fails, an error is thrown.
 */
export declare const maxRetries: number | undefined;
/**
 * The profile for API operations. If not set, the default profile created with `aws configure` will be used.
 */
export declare const profile: string | undefined;
/**
 * The region where AWS operations will take place. Examples are `us-east-1`, `us-west-2`, etc.
 */
export declare const region: Region | undefined;
/**
 * The Amazon Resource Name (ARN) of the AWS Identity and Access Management (IAM) role for Cloud Control API to use when performing this resource operation. Note, this is a unique feature for server side security enforcement, not to be confused with assumeRole, which is used to obtain temporary client credentials. If you do not specify a role, Cloud Control API uses a temporary session created using your AWS user credentials instead.
 */
export declare const roleArn: string | undefined;
/**
 * Set this to true to force the request to use path-style addressing, i.e., `http://s3.amazonaws.com/BUCKET/KEY`. By default, the S3 client will use virtual hosted bucket addressing when possible (`http://BUCKET.s3.amazonaws.com/KEY`). Specific to the Amazon S3 service.
 */
export declare const s3ForcePathStyle: boolean | undefined;
/**
 * The secret key for API operations. You can retrieve this from the 'Security & Credentials' section of the AWS console.
 */
export declare const secretKey: string | undefined;
/**
 * The path to the shared credentials file. If not set this defaults to `~/.aws/credentials`.
 */
export declare const sharedCredentialsFile: string | undefined;
/**
 * Skip the credentials validation via STS API. Used for AWS API implementations that do not have STS available/implemented.
 */
export declare const skipCredentialsValidation: boolean;
/**
 * Skip getting the supported EC2 platforms. Used by users that don't have `ec2:DescribeAccountAttributes` permissions.
 */
export declare const skipGetEc2Platforms: boolean;
/**
 * Skip the AWS Metadata API check. Useful for AWS API implementations that do not have a metadata API endpoint. Setting to true prevents Pulumi from authenticating via the Metadata API. You may need to use other authentication methods like static credentials, configuration variables, or environment variables.
 */
export declare const skipMetadataApiCheck: boolean;
/**
 * Skip static validation of region name. Used by users of alternative AWS-like APIs or users with access to regions that are not public.
 */
export declare const skipRegionValidation: boolean;
/**
 * Skip requesting the account ID. Used for AWS API implementations that do not have IAM/STS API and/or metadata API.
 */
export declare const skipRequestingAccountId: boolean | undefined;
/**
 * Session token for validating temporary credentials. Typically provided after successful identity federation or Multi-Factor Authentication (MFA) login. With MFA login, this is the session token provided afterward, not the 6 digit MFA code used to get temporary credentials.
 */
export declare const token: string | undefined;
