import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Connect::AgentStatus
 */
export declare class AgentStatus extends pulumi.CustomResource {
    /**
     * Get an existing AgentStatus resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): AgentStatus;
    /**
     * Returns true if the given object is an instance of AgentStatus.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is AgentStatus;
    /**
     * The Amazon Resource Name (ARN) of the agent status.
     */
    readonly agentStatusArn: pulumi.Output<string>;
    /**
     * The description of the status.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The display order of the status.
     */
    readonly displayOrder: pulumi.Output<number | undefined>;
    /**
     * The identifier of the Amazon Connect instance.
     */
    readonly instanceArn: pulumi.Output<string>;
    /**
     * Last modified region.
     */
    readonly lastModifiedRegion: pulumi.Output<string>;
    /**
     * Last modified time.
     */
    readonly lastModifiedTime: pulumi.Output<number>;
    /**
     * The name of the status.
     */
    readonly name: pulumi.Output<string>;
    /**
     * A number indicating the reset order of the agent status.
     */
    readonly resetOrderNumber: pulumi.Output<boolean | undefined>;
    /**
     * The state of the status.
     */
    readonly state: pulumi.Output<enums.connect.AgentStatusState>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The type of agent status.
     */
    readonly type: pulumi.Output<enums.connect.AgentStatusType | undefined>;
    /**
     * Create a AgentStatus resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: AgentStatusArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a AgentStatus resource.
 */
export interface AgentStatusArgs {
    /**
     * The description of the status.
     */
    description?: pulumi.Input<string>;
    /**
     * The display order of the status.
     */
    displayOrder?: pulumi.Input<number>;
    /**
     * The identifier of the Amazon Connect instance.
     */
    instanceArn: pulumi.Input<string>;
    /**
     * The name of the status.
     */
    name?: pulumi.Input<string>;
    /**
     * A number indicating the reset order of the agent status.
     */
    resetOrderNumber?: pulumi.Input<boolean>;
    /**
     * The state of the status.
     */
    state: pulumi.Input<enums.connect.AgentStatusState>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The type of agent status.
     */
    type?: pulumi.Input<enums.connect.AgentStatusType>;
}
