import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Connect::TaskTemplate.
 */
export declare function getTaskTemplate(args: GetTaskTemplateArgs, opts?: pulumi.InvokeOptions): Promise<GetTaskTemplateResult>;
export interface GetTaskTemplateArgs {
    /**
     * The identifier (arn) of the task template.
     */
    arn: string;
}
export interface GetTaskTemplateResult {
    /**
     * The identifier (arn) of the task template.
     */
    readonly arn?: string;
    /**
     * A unique, case-sensitive identifier that you provide to ensure the idempotency of the request.
     */
    readonly clientToken?: string;
    /**
     * The constraints for the task template
     */
    readonly constraints?: outputs.connect.ConstraintsProperties;
    /**
     * The identifier of the contact flow.
     */
    readonly contactFlowArn?: string;
    /**
     * The default values for fields when a task is created by referencing this template.
     */
    readonly defaults?: outputs.connect.TaskTemplateDefaultFieldValue[];
    /**
     * The description of the task template.
     */
    readonly description?: string;
    /**
     * The list of task template's fields
     */
    readonly fields?: outputs.connect.TaskTemplateField[];
    /**
     * The identifier (arn) of the instance.
     */
    readonly instanceArn?: string;
    /**
     * The name of the task template.
     */
    readonly name?: string;
    /**
     * The identifier of the contact flow.
     */
    readonly selfAssignContactFlowArn?: string;
    /**
     * The status of the task template.
     */
    readonly status?: enums.connect.TaskTemplateStatus;
    /**
     * One or more tags.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::Connect::TaskTemplate.
 */
export declare function getTaskTemplateOutput(args: GetTaskTemplateOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetTaskTemplateResult>;
export interface GetTaskTemplateOutputArgs {
    /**
     * The identifier (arn) of the task template.
     */
    arn: pulumi.Input<string>;
}
