import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * An event trigger resource of Amazon Connect Customer Profiles
 */
export declare class EventTrigger extends pulumi.CustomResource {
    /**
     * Get an existing EventTrigger resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): EventTrigger;
    /**
     * Returns true if the given object is an instance of EventTrigger.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EventTrigger;
    /**
     * The timestamp of when the event trigger was created.
     */
    readonly createdAt: pulumi.Output<string>;
    /**
     * The description of the event trigger.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The unique name of the domain.
     */
    readonly domainName: pulumi.Output<string>;
    /**
     * A list of conditions that determine when an event should trigger the destination.
     */
    readonly eventTriggerConditions: pulumi.Output<outputs.customerprofiles.EventTriggerCondition[]>;
    /**
     * Defines limits controlling whether an event triggers the destination, based on ingestion latency and the number of invocations per profile over specific time periods.
     */
    readonly eventTriggerLimits: pulumi.Output<outputs.customerprofiles.EventTriggerLimits | undefined>;
    /**
     * The unique name of the event trigger.
     */
    readonly eventTriggerName: pulumi.Output<string>;
    /**
     * The timestamp of when the event trigger was most recently updated.
     */
    readonly lastUpdatedAt: pulumi.Output<string>;
    /**
     * The unique name of the object type.
     */
    readonly objectTypeName: pulumi.Output<string>;
    /**
     * The destination is triggered only for profiles that meet the criteria of a segment definition.
     */
    readonly segmentFilter: pulumi.Output<string | undefined>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a EventTrigger resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EventTriggerArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a EventTrigger resource.
 */
export interface EventTriggerArgs {
    /**
     * The description of the event trigger.
     */
    description?: pulumi.Input<string>;
    /**
     * The unique name of the domain.
     */
    domainName: pulumi.Input<string>;
    /**
     * A list of conditions that determine when an event should trigger the destination.
     */
    eventTriggerConditions: pulumi.Input<pulumi.Input<inputs.customerprofiles.EventTriggerConditionArgs>[]>;
    /**
     * Defines limits controlling whether an event triggers the destination, based on ingestion latency and the number of invocations per profile over specific time periods.
     */
    eventTriggerLimits?: pulumi.Input<inputs.customerprofiles.EventTriggerLimitsArgs>;
    /**
     * The unique name of the event trigger.
     */
    eventTriggerName?: pulumi.Input<string>;
    /**
     * The unique name of the object type.
     */
    objectTypeName: pulumi.Input<string>;
    /**
     * The destination is triggered only for profiles that meet the criteria of a segment definition.
     */
    segmentFilter?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
