import * as pulumi from "@pulumi/pulumi";
/**
 * Connections enables users to connect their DataZone resources (domains, projects, and environments) to external resources/services (data, compute, etc)
 */
export declare function getConnection(args: GetConnectionArgs, opts?: pulumi.InvokeOptions): Promise<GetConnectionResult>;
export interface GetConnectionArgs {
    /**
     * The ID of the connection.
     */
    connectionId: string;
    /**
     * The ID of the domain in which the connection is created.
     */
    domainId: string;
}
export interface GetConnectionResult {
    /**
     * The ID of the connection.
     */
    readonly connectionId?: string;
    /**
     * The description of the connection.
     */
    readonly description?: string;
    /**
     * The ID of the domain in which the connection is created.
     */
    readonly domainId?: string;
    /**
     * The ID of the domain unit in which the connection is created.
     */
    readonly domainUnitId?: string;
    /**
     * The ID of the environment in which the connection is created.
     */
    readonly environmentId?: string;
    /**
     * The role of the user in the environment.
     */
    readonly environmentUserRole?: string;
    /**
     * The ID of the project in which the connection is created.
     */
    readonly projectId?: string;
    /**
     * The type of the connection.
     */
    readonly type?: string;
}
/**
 * Connections enables users to connect their DataZone resources (domains, projects, and environments) to external resources/services (data, compute, etc)
 */
export declare function getConnectionOutput(args: GetConnectionOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetConnectionResult>;
export interface GetConnectionOutputArgs {
    /**
     * The ID of the connection.
     */
    connectionId: pulumi.Input<string>;
    /**
     * The ID of the domain in which the connection is created.
     */
    domainId: pulumi.Input<string>;
}
