import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Deadline::Fleet Resource Type
 */
export declare class Fleet extends pulumi.CustomResource {
    /**
     * Get an existing Fleet resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Fleet;
    /**
     * Returns true if the given object is an instance of Fleet.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Fleet;
    /**
     * The Amazon Resource Name (ARN) assigned to the fleet.
     */
    readonly arn: pulumi.Output<string>;
    readonly capabilities: pulumi.Output<outputs.deadline.FleetCapabilities>;
    /**
     * The configuration details for the fleet.
     */
    readonly configuration: pulumi.Output<outputs.deadline.FleetConfiguration0Properties | outputs.deadline.FleetConfiguration1Properties>;
    /**
     * A description that helps identify what the fleet is used for.
     *
     * > This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The display name of the fleet summary to update.
     *
     * > This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
     */
    readonly displayName: pulumi.Output<string>;
    /**
     * The farm ID.
     */
    readonly farmId: pulumi.Output<string>;
    /**
     * The fleet ID.
     */
    readonly fleetId: pulumi.Output<string>;
    /**
     * The maximum number of workers specified in the fleet.
     */
    readonly maxWorkerCount: pulumi.Output<number>;
    /**
     * The minimum number of workers in the fleet.
     */
    readonly minWorkerCount: pulumi.Output<number | undefined>;
    /**
     * The IAM role that workers in the fleet use when processing jobs.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * The status of the fleet.
     */
    readonly status: pulumi.Output<enums.deadline.FleetStatus>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The number of workers in the fleet summary.
     */
    readonly workerCount: pulumi.Output<number>;
    /**
     * Create a Fleet resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: FleetArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Fleet resource.
 */
export interface FleetArgs {
    /**
     * The configuration details for the fleet.
     */
    configuration: pulumi.Input<inputs.deadline.FleetConfiguration0PropertiesArgs | inputs.deadline.FleetConfiguration1PropertiesArgs>;
    /**
     * A description that helps identify what the fleet is used for.
     *
     * > This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
     */
    description?: pulumi.Input<string>;
    /**
     * The display name of the fleet summary to update.
     *
     * > This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
     */
    displayName: pulumi.Input<string>;
    /**
     * The farm ID.
     */
    farmId: pulumi.Input<string>;
    /**
     * The maximum number of workers specified in the fleet.
     */
    maxWorkerCount: pulumi.Input<number>;
    /**
     * The minimum number of workers in the fleet.
     */
    minWorkerCount?: pulumi.Input<number>;
    /**
     * The IAM role that workers in the fleet use when processing jobs.
     */
    roleArn: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
