import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::Deadline::StorageProfile Resource Type
 */
export declare function getStorageProfile(args: GetStorageProfileArgs, opts?: pulumi.InvokeOptions): Promise<GetStorageProfileResult>;
export interface GetStorageProfileArgs {
    /**
     * The unique identifier of the farm that contains the storage profile.
     */
    farmId: string;
    /**
     * The storage profile ID.
     */
    storageProfileId: string;
}
export interface GetStorageProfileResult {
    /**
     * The display name of the storage profile summary to update.
     *
     * > This field can store any content. Escape or encode this content before displaying it on a webpage or any other system that might interpret the content of this field.
     */
    readonly displayName?: string;
    /**
     * Operating system specific file system path to the storage location.
     */
    readonly fileSystemLocations?: outputs.deadline.StorageProfileFileSystemLocation[];
    /**
     * The operating system (OS) family.
     */
    readonly osFamily?: enums.deadline.StorageProfileOperatingSystemFamily;
    /**
     * The storage profile ID.
     */
    readonly storageProfileId?: string;
}
/**
 * Definition of AWS::Deadline::StorageProfile Resource Type
 */
export declare function getStorageProfileOutput(args: GetStorageProfileOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetStorageProfileResult>;
export interface GetStorageProfileOutputArgs {
    /**
     * The unique identifier of the farm that contains the storage profile.
     */
    farmId: pulumi.Input<string>;
    /**
     * The storage profile ID.
     */
    storageProfileId: pulumi.Input<string>;
}
