import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * AWS::DeviceFarm::TestGridProject creates a new TestGrid Project
 */
export declare function getTestGridProject(args: GetTestGridProjectArgs, opts?: pulumi.InvokeOptions): Promise<GetTestGridProjectResult>;
export interface GetTestGridProjectArgs {
    /**
     * The Amazon Resource Name (ARN) of the `TestGrid` project. See [Amazon resource names](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html) in the *General Reference guide* .
     */
    arn: string;
}
export interface GetTestGridProjectResult {
    /**
     * The Amazon Resource Name (ARN) of the `TestGrid` project. See [Amazon resource names](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html) in the *General Reference guide* .
     */
    readonly arn?: string;
    /**
     * A human-readable description for the project.
     */
    readonly description?: string;
    /**
     * A human-readable name for the project.
     */
    readonly name?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) in the *guide* .
     */
    readonly tags?: outputs.Tag[];
}
/**
 * AWS::DeviceFarm::TestGridProject creates a new TestGrid Project
 */
export declare function getTestGridProjectOutput(args: GetTestGridProjectOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetTestGridProjectResult>;
export interface GetTestGridProjectOutputArgs {
    /**
     * The Amazon Resource Name (ARN) of the `TestGrid` project. See [Amazon resource names](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html) in the *General Reference guide* .
     */
    arn: pulumi.Input<string>;
}
