import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * AWS::DeviceFarm::TestGridProject creates a new TestGrid Project
 */
export declare class TestGridProject extends pulumi.CustomResource {
    /**
     * Get an existing TestGridProject resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TestGridProject;
    /**
     * Returns true if the given object is an instance of TestGridProject.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TestGridProject;
    /**
     * The Amazon Resource Name (ARN) of the `TestGrid` project. See [Amazon resource names](https://docs.aws.amazon.com/general/latest/gr/aws-arns-and-namespaces.html) in the *General Reference guide* .
     */
    readonly arn: pulumi.Output<string>;
    /**
     * A human-readable description for the project.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * A human-readable name for the project.
     */
    readonly name: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) in the *guide* .
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The VPC security groups and subnets that are attached to a project.
     */
    readonly vpcConfig: pulumi.Output<outputs.devicefarm.TestGridProjectVpcConfig | undefined>;
    /**
     * Create a TestGridProject resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: TestGridProjectArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TestGridProject resource.
 */
export interface TestGridProjectArgs {
    /**
     * A human-readable description for the project.
     */
    description?: pulumi.Input<string>;
    /**
     * A human-readable name for the project.
     */
    name?: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     *
     * For more information, see [Tag](https://docs.aws.amazon.com/AWSCloudFormation/latest/UserGuide/aws-properties-resource-tags.html) in the *guide* .
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The VPC security groups and subnets that are attached to a project.
     */
    vpcConfig?: pulumi.Input<inputs.devicefarm.TestGridProjectVpcConfigArgs>;
}
