import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Schema of AWS::EC2::IPAMResourceDiscovery Type
 */
export declare class IpamResourceDiscovery extends pulumi.CustomResource {
    /**
     * Get an existing IpamResourceDiscovery resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): IpamResourceDiscovery;
    /**
     * Returns true if the given object is an instance of IpamResourceDiscovery.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is IpamResourceDiscovery;
    /**
     * The resource discovery description.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * Amazon Resource Name (Arn) for the Resource Discovery.
     */
    readonly ipamResourceDiscoveryArn: pulumi.Output<string>;
    /**
     * Id of the IPAM Pool.
     */
    readonly ipamResourceDiscoveryId: pulumi.Output<string>;
    /**
     * The region the resource discovery is setup in.
     */
    readonly ipamResourceDiscoveryRegion: pulumi.Output<string>;
    /**
     * Determines whether or not address space from this pool is publicly advertised. Must be set if and only if the pool is IPv6.
     */
    readonly isDefault: pulumi.Output<boolean>;
    /**
     * The regions Resource Discovery is enabled for. Allows resource discoveries to be created in these regions, as well as enabling monitoring
     */
    readonly operatingRegions: pulumi.Output<outputs.ec2.IpamResourceDiscoveryIpamOperatingRegion[] | undefined>;
    /**
     * A set of organizational unit (OU) exclusions for this resource.
     */
    readonly organizationalUnitExclusions: pulumi.Output<outputs.ec2.IpamResourceDiscoveryOrganizationalUnitExclusion[] | undefined>;
    /**
     * Owner Account ID of the Resource Discovery
     */
    readonly ownerId: pulumi.Output<string>;
    /**
     * The state of this Resource Discovery.
     */
    readonly state: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a IpamResourceDiscovery resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: IpamResourceDiscoveryArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a IpamResourceDiscovery resource.
 */
export interface IpamResourceDiscoveryArgs {
    /**
     * The resource discovery description.
     */
    description?: pulumi.Input<string>;
    /**
     * The regions Resource Discovery is enabled for. Allows resource discoveries to be created in these regions, as well as enabling monitoring
     */
    operatingRegions?: pulumi.Input<pulumi.Input<inputs.ec2.IpamResourceDiscoveryIpamOperatingRegionArgs>[]>;
    /**
     * A set of organizational unit (OU) exclusions for this resource.
     */
    organizationalUnitExclusions?: pulumi.Input<pulumi.Input<inputs.ec2.IpamResourceDiscoveryOrganizationalUnitExclusionArgs>[]>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
