import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * VPC Route Server Peer
 */
export declare class RouteServerPeer extends pulumi.CustomResource {
    /**
     * Get an existing RouteServerPeer resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): RouteServerPeer;
    /**
     * Returns true if the given object is an instance of RouteServerPeer.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RouteServerPeer;
    /**
     * The Amazon Resource Name (ARN) of the Route Server Peer.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the Route Server Peer.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The BGP configuration options for this peer, including ASN (Autonomous System Number) and BFD (Bidrectional Forwarding Detection) settings.
     */
    readonly bgpOptions: pulumi.Output<outputs.ec2.RouteServerPeerBgpOptions>;
    /**
     * Elastic Network Interface IP address owned by the Route Server Endpoint
     */
    readonly endpointEniAddress: pulumi.Output<string>;
    /**
     * Elastic Network Interface ID owned by the Route Server Endpoint
     */
    readonly endpointEniId: pulumi.Output<string>;
    /**
     * IP address of the Route Server Peer
     */
    readonly peerAddress: pulumi.Output<string>;
    /**
     * Route Server Endpoint ID
     */
    readonly routeServerEndpointId: pulumi.Output<string>;
    /**
     * Route Server ID
     */
    readonly routeServerId: pulumi.Output<string>;
    /**
     * Subnet ID
     */
    readonly subnetId: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * VPC ID
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a RouteServerPeer resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: RouteServerPeerArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a RouteServerPeer resource.
 */
export interface RouteServerPeerArgs {
    /**
     * The BGP configuration options for this peer, including ASN (Autonomous System Number) and BFD (Bidrectional Forwarding Detection) settings.
     */
    bgpOptions: pulumi.Input<inputs.ec2.RouteServerPeerBgpOptionsArgs>;
    /**
     * IP address of the Route Server Peer
     */
    peerAddress: pulumi.Input<string>;
    /**
     * Route Server Endpoint ID
     */
    routeServerEndpointId: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
