import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::ElastiCache::SubnetGroup
 */
export declare class SubnetGroup extends pulumi.CustomResource {
    /**
     * Get an existing SubnetGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): SubnetGroup;
    /**
     * Returns true if the given object is an instance of SubnetGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is SubnetGroup;
    /**
     * The name for the cache subnet group. This value is stored as a lowercase string.
     */
    readonly cacheSubnetGroupName: pulumi.Output<string | undefined>;
    /**
     * The description for the cache subnet group.
     */
    readonly description: pulumi.Output<string>;
    /**
     * The EC2 subnet IDs for the cache subnet group.
     */
    readonly subnetIds: pulumi.Output<string[]>;
    /**
     * A tag that can be added to an ElastiCache subnet group. Tags are composed of a Key/Value pair. You can use tags to categorize and track all your subnet groups. A tag with a null Value is permitted.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a SubnetGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: SubnetGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a SubnetGroup resource.
 */
export interface SubnetGroupArgs {
    /**
     * The name for the cache subnet group. This value is stored as a lowercase string.
     */
    cacheSubnetGroupName?: pulumi.Input<string>;
    /**
     * The description for the cache subnet group.
     */
    description: pulumi.Input<string>;
    /**
     * The EC2 subnet IDs for the cache subnet group.
     */
    subnetIds: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * A tag that can be added to an ElastiCache subnet group. Tags are composed of a Key/Value pair. You can use tags to categorize and track all your subnet groups. A tag with a null Value is permitted.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
