import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * MatchingWorkflow defined in AWS Entity Resolution service
 */
export declare class MatchingWorkflow extends pulumi.CustomResource {
    /**
     * Get an existing MatchingWorkflow resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): MatchingWorkflow;
    /**
     * Returns true if the given object is an instance of MatchingWorkflow.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MatchingWorkflow;
    readonly createdAt: pulumi.Output<string>;
    /**
     * The description of the MatchingWorkflow
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * An object which defines an incremental run type and has only `incrementalRunType` as a field.
     */
    readonly incrementalRunConfig: pulumi.Output<outputs.entityresolution.MatchingWorkflowIncrementalRunConfig | undefined>;
    /**
     * A list of `InputSource` objects, which have the fields `InputSourceARN` and `SchemaName` .
     */
    readonly inputSourceConfig: pulumi.Output<outputs.entityresolution.MatchingWorkflowInputSource[]>;
    /**
     * A list of `OutputSource` objects, each of which contains fields `OutputS3Path` , `ApplyNormalization` , and `Output` .
     */
    readonly outputSourceConfig: pulumi.Output<outputs.entityresolution.MatchingWorkflowOutputSource[]>;
    /**
     * An object which defines the `resolutionType` and the `ruleBasedProperties` .
     */
    readonly resolutionTechniques: pulumi.Output<outputs.entityresolution.MatchingWorkflowResolutionTechniques>;
    /**
     * The Amazon Resource Name (ARN) of the IAM role. AWS Entity Resolution assumes this role to create resources on your behalf as part of workflow execution.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * The tags used to organize, track, or control access for this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    readonly updatedAt: pulumi.Output<string>;
    readonly workflowArn: pulumi.Output<string>;
    /**
     * The name of the MatchingWorkflow
     */
    readonly workflowName: pulumi.Output<string>;
    /**
     * Create a MatchingWorkflow resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MatchingWorkflowArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a MatchingWorkflow resource.
 */
export interface MatchingWorkflowArgs {
    /**
     * The description of the MatchingWorkflow
     */
    description?: pulumi.Input<string>;
    /**
     * An object which defines an incremental run type and has only `incrementalRunType` as a field.
     */
    incrementalRunConfig?: pulumi.Input<inputs.entityresolution.MatchingWorkflowIncrementalRunConfigArgs>;
    /**
     * A list of `InputSource` objects, which have the fields `InputSourceARN` and `SchemaName` .
     */
    inputSourceConfig: pulumi.Input<pulumi.Input<inputs.entityresolution.MatchingWorkflowInputSourceArgs>[]>;
    /**
     * A list of `OutputSource` objects, each of which contains fields `OutputS3Path` , `ApplyNormalization` , and `Output` .
     */
    outputSourceConfig: pulumi.Input<pulumi.Input<inputs.entityresolution.MatchingWorkflowOutputSourceArgs>[]>;
    /**
     * An object which defines the `resolutionType` and the `ruleBasedProperties` .
     */
    resolutionTechniques: pulumi.Input<inputs.entityresolution.MatchingWorkflowResolutionTechniquesArgs>;
    /**
     * The Amazon Resource Name (ARN) of the IAM role. AWS Entity Resolution assumes this role to create resources on your behalf as part of workflow execution.
     */
    roleArn: pulumi.Input<string>;
    /**
     * The tags used to organize, track, or control access for this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
    /**
     * The name of the MatchingWorkflow
     */
    workflowName?: pulumi.Input<string>;
}
