import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * A resource schema for an EventType in Amazon Fraud Detector.
 */
export declare class EventType extends pulumi.CustomResource {
    /**
     * Get an existing EventType resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): EventType;
    /**
     * Returns true if the given object is an instance of EventType.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EventType;
    /**
     * The ARN of the event type.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The time when the event type was created.
     */
    readonly createdTime: pulumi.Output<string>;
    /**
     * The description of the event type.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The event type entity types.
     */
    readonly entityTypes: pulumi.Output<outputs.frauddetector.EventTypeEntityType[]>;
    /**
     * The event type event variables.
     */
    readonly eventVariables: pulumi.Output<outputs.frauddetector.EventTypeEventVariable[]>;
    /**
     * The event type labels.
     */
    readonly labels: pulumi.Output<outputs.frauddetector.EventTypeLabel[]>;
    /**
     * The time when the event type was last updated.
     */
    readonly lastUpdatedTime: pulumi.Output<string>;
    /**
     * The name for the event type
     */
    readonly name: pulumi.Output<string>;
    /**
     * Tags associated with this event type.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a EventType resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EventTypeArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a EventType resource.
 */
export interface EventTypeArgs {
    /**
     * The description of the event type.
     */
    description?: pulumi.Input<string>;
    /**
     * The event type entity types.
     */
    entityTypes: pulumi.Input<pulumi.Input<inputs.frauddetector.EventTypeEntityTypeArgs>[]>;
    /**
     * The event type event variables.
     */
    eventVariables: pulumi.Input<pulumi.Input<inputs.frauddetector.EventTypeEventVariableArgs>[]>;
    /**
     * The event type labels.
     */
    labels: pulumi.Input<pulumi.Input<inputs.frauddetector.EventTypeLabelArgs>[]>;
    /**
     * The name for the event type
     */
    name?: pulumi.Input<string>;
    /**
     * Tags associated with this event type.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
