import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * An invoice unit is a set of mutually exclusive accounts that correspond to your business entity. Invoice units allow you to separate AWS account costs and configures your invoice for each business entity.
 */
export declare function getInvoiceUnit(args: GetInvoiceUnitArgs, opts?: pulumi.InvokeOptions): Promise<GetInvoiceUnitResult>;
export interface GetInvoiceUnitArgs {
    /**
     * The ARN to identify an invoice unit. This information can't be modified or deleted.
     */
    invoiceUnitArn: string;
}
export interface GetInvoiceUnitResult {
    /**
     * The assigned description for an invoice unit. This information can't be modified or deleted.
     */
    readonly description?: string;
    /**
     * The ARN to identify an invoice unit. This information can't be modified or deleted.
     */
    readonly invoiceUnitArn?: string;
    /**
     * The last time the invoice unit was updated. This is important to determine the version of invoice unit configuration used to create the invoices. Any invoice created after this modified time will use this invoice unit configuration.
     */
    readonly lastModified?: number;
    /**
     * The tag structure that contains a tag key and value.
     */
    readonly resourceTags?: outputs.Tag[];
    /**
     * An `InvoiceUnitRule` object used the categorize invoice units.
     */
    readonly rule?: outputs.invoicing.InvoiceUnitRule;
    /**
     * Whether the invoice unit based tax inheritance is/ should be enabled or disabled.
     */
    readonly taxInheritanceDisabled?: boolean;
}
/**
 * An invoice unit is a set of mutually exclusive accounts that correspond to your business entity. Invoice units allow you to separate AWS account costs and configures your invoice for each business entity.
 */
export declare function getInvoiceUnitOutput(args: GetInvoiceUnitOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetInvoiceUnitResult>;
export interface GetInvoiceUnitOutputArgs {
    /**
     * The ARN to identify an invoice unit. This information can't be modified or deleted.
     */
    invoiceUnitArn: pulumi.Input<string>;
}
