import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Mitigation actions can be used to take actions to mitigate issues that were found in an Audit finding or Detect violation.
 */
export declare class MitigationAction extends pulumi.CustomResource {
    /**
     * Get an existing MitigationAction resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): MitigationAction;
    /**
     * Returns true if the given object is an instance of MitigationAction.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MitigationAction;
    /**
     * A unique identifier for the mitigation action.
     */
    readonly actionName: pulumi.Output<string | undefined>;
    /**
     * The set of parameters for this mitigation action. The parameters vary, depending on the kind of action you apply.
     */
    readonly actionParams: pulumi.Output<outputs.iot.MitigationActionActionParams>;
    /**
     * The Amazon Resource Name (ARN) of the mitigation action.
     */
    readonly mitigationActionArn: pulumi.Output<string>;
    /**
     * The ID of the mitigation action.
     */
    readonly mitigationActionId: pulumi.Output<string>;
    /**
     * The IAM role ARN used to apply this mitigation action.
     */
    readonly roleArn: pulumi.Output<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a MitigationAction resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MitigationActionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a MitigationAction resource.
 */
export interface MitigationActionArgs {
    /**
     * A unique identifier for the mitigation action.
     */
    actionName?: pulumi.Input<string>;
    /**
     * The set of parameters for this mitigation action. The parameters vary, depending on the kind of action you apply.
     */
    actionParams: pulumi.Input<inputs.iot.MitigationActionActionParamsArgs>;
    /**
     * The IAM role ARN used to apply this mitigation action.
     */
    roleArn: pulumi.Input<string>;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
