import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::IVS::Channel
 */
export declare function getChannel(args: GetChannelArgs, opts?: pulumi.InvokeOptions): Promise<GetChannelResult>;
export interface GetChannelArgs {
    /**
     * Channel ARN is automatically generated on creation and assigned as the unique identifier.
     */
    arn: string;
}
export interface GetChannelResult {
    /**
     * Channel ARN is automatically generated on creation and assigned as the unique identifier.
     */
    readonly arn?: string;
    /**
     * Whether the channel is authorized.
     */
    readonly authorized?: boolean;
    /**
     * Indicates which content-packaging format is used (MPEG-TS or fMP4). If multitrackInputConfiguration is specified and enabled is true, then containerFormat is required and must be set to FRAGMENTED_MP4. Otherwise, containerFormat may be set to TS or FRAGMENTED_MP4. Default: TS.
     */
    readonly containerFormat?: enums.ivs.ChannelContainerFormat;
    /**
     * Channel ingest endpoint, part of the definition of an ingest server, used when you set up streaming software.
     */
    readonly ingestEndpoint?: string;
    /**
     * Whether the channel allows insecure ingest.
     */
    readonly insecureIngest?: boolean;
    /**
     * Channel latency mode.
     */
    readonly latencyMode?: enums.ivs.ChannelLatencyMode;
    /**
     * Object specifying multitrack input configuration. Default: no multitrack input configuration is specified.
     */
    readonly multitrackInputConfiguration?: outputs.ivs.ChannelMultitrackInputConfiguration;
    /**
     * Channel
     */
    readonly name?: string;
    /**
     * Channel Playback URL.
     */
    readonly playbackUrl?: string;
    /**
     * Optional transcode preset for the channel. This is selectable only for ADVANCED_HD and ADVANCED_SD channel types. For those channel types, the default preset is HIGHER_BANDWIDTH_DELIVERY. For other channel types (BASIC and STANDARD), preset is the empty string ("").
     */
    readonly preset?: enums.ivs.ChannelPreset;
    /**
     * Recording Configuration ARN. A value other than an empty string indicates that recording is enabled. Default: "" (recording is disabled).
     */
    readonly recordingConfigurationArn?: string;
    /**
     * A list of key-value pairs that contain metadata for the asset model.
     */
    readonly tags?: outputs.Tag[];
    /**
     * Channel type, which determines the allowable resolution and bitrate. If you exceed the allowable resolution or bitrate, the stream probably will disconnect immediately.
     */
    readonly type?: enums.ivs.ChannelType;
}
/**
 * Resource Type definition for AWS::IVS::Channel
 */
export declare function getChannelOutput(args: GetChannelOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetChannelResult>;
export interface GetChannelOutputArgs {
    /**
     * Channel ARN is automatically generated on creation and assigned as the unique identifier.
     */
    arn: pulumi.Input<string>;
}
