import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::IVS::PlaybackRestrictionPolicy.
 */
export declare function getPlaybackRestrictionPolicy(args: GetPlaybackRestrictionPolicyArgs, opts?: pulumi.InvokeOptions): Promise<GetPlaybackRestrictionPolicyResult>;
export interface GetPlaybackRestrictionPolicyArgs {
    /**
     * Playback-restriction-policy identifier.
     */
    arn: string;
}
export interface GetPlaybackRestrictionPolicyResult {
    /**
     * A list of country codes that control geoblocking restriction. Allowed values are the officially assigned ISO 3166-1 alpha-2 codes. Default: All countries (an empty array).
     */
    readonly allowedCountries?: string[];
    /**
     * A list of origin sites that control CORS restriction. Allowed values are the same as valid values of the Origin header defined at https://developer.mozilla.org/en-US/docs/Web/HTTP/Headers/Origin
     */
    readonly allowedOrigins?: string[];
    /**
     * Playback-restriction-policy identifier.
     */
    readonly arn?: string;
    /**
     * Whether channel playback is constrained by origin site.
     */
    readonly enableStrictOriginEnforcement?: boolean;
    /**
     * Playback-restriction-policy name.
     */
    readonly name?: string;
    /**
     * An array of key-value pairs to apply to this resource.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::IVS::PlaybackRestrictionPolicy.
 */
export declare function getPlaybackRestrictionPolicyOutput(args: GetPlaybackRestrictionPolicyOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetPlaybackRestrictionPolicyResult>;
export interface GetPlaybackRestrictionPolicyOutputArgs {
    /**
     * Playback-restriction-policy identifier.
     */
    arn: pulumi.Input<string>;
}
