import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Creates an Amazon Kinesis Data Analytics application. For information about creating a Kinesis Data Analytics application, see [Creating an Application](https://docs.aws.amazon.com/kinesisanalytics/latest/java/getting-started.html).
 */
export declare function getApplication(args: GetApplicationArgs, opts?: pulumi.InvokeOptions): Promise<GetApplicationResult>;
export interface GetApplicationArgs {
    /**
     * The name of the application.
     */
    applicationName: string;
}
export interface GetApplicationResult {
    /**
     * Use this parameter to configure the application.
     */
    readonly applicationConfiguration?: outputs.kinesisanalyticsv2.ApplicationConfiguration;
    /**
     * The description of the application.
     */
    readonly applicationDescription?: string;
    /**
     * Used to configure start of maintenance window.
     */
    readonly applicationMaintenanceConfiguration?: outputs.kinesisanalyticsv2.ApplicationMaintenanceConfiguration;
    /**
     * The runtime environment for the application.
     */
    readonly runtimeEnvironment?: string;
    /**
     * Specifies the IAM role that the application uses to access external resources.
     */
    readonly serviceExecutionRole?: string;
    /**
     * A list of one or more tags to assign to the application. A tag is a key-value pair that identifies an application. Note that the maximum number of application tags includes system tags. The maximum number of user-defined application tags is 50.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Creates an Amazon Kinesis Data Analytics application. For information about creating a Kinesis Data Analytics application, see [Creating an Application](https://docs.aws.amazon.com/kinesisanalytics/latest/java/getting-started.html).
 */
export declare function getApplicationOutput(args: GetApplicationOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetApplicationResult>;
export interface GetApplicationOutputArgs {
    /**
     * The name of the application.
     */
    applicationName: pulumi.Input<string>;
}
