import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::Lambda::Version
 */
export declare class Version extends pulumi.CustomResource {
    /**
     * Get an existing Version resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): Version;
    /**
     * Returns true if the given object is an instance of Version.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is Version;
    /**
     * Only publish a version if the hash value matches the value that's specified. Use this option to avoid publishing a version if the function code has changed since you last updated it. Updates are not supported for this property.
     */
    readonly codeSha256: pulumi.Output<string | undefined>;
    /**
     * A description for the version to override the description in the function configuration. Updates are not supported for this property.
     */
    readonly description: pulumi.Output<string | undefined>;
    /**
     * The ARN of the version.
     */
    readonly functionArn: pulumi.Output<string>;
    /**
     * The name of the Lambda function.
     */
    readonly functionName: pulumi.Output<string>;
    /**
     * Specifies a provisioned concurrency configuration for a function's version. Updates are not supported for this property.
     */
    readonly provisionedConcurrencyConfig: pulumi.Output<outputs.lambda.VersionProvisionedConcurrencyConfiguration | undefined>;
    /**
     * Specifies the runtime management configuration of a function. Displays runtimeVersionArn only for Manual.
     */
    readonly runtimePolicy: pulumi.Output<outputs.lambda.VersionRuntimePolicy | undefined>;
    /**
     * The version number.
     */
    readonly version: pulumi.Output<string>;
    /**
     * Create a Version resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VersionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a Version resource.
 */
export interface VersionArgs {
    /**
     * Only publish a version if the hash value matches the value that's specified. Use this option to avoid publishing a version if the function code has changed since you last updated it. Updates are not supported for this property.
     */
    codeSha256?: pulumi.Input<string>;
    /**
     * A description for the version to override the description in the function configuration. Updates are not supported for this property.
     */
    description?: pulumi.Input<string>;
    /**
     * The name of the Lambda function.
     */
    functionName: pulumi.Input<string>;
    /**
     * Specifies a provisioned concurrency configuration for a function's version. Updates are not supported for this property.
     */
    provisionedConcurrencyConfig?: pulumi.Input<inputs.lambda.VersionProvisionedConcurrencyConfigurationArgs>;
    /**
     * Specifies the runtime management configuration of a function. Displays runtimeVersionArn only for Manual.
     */
    runtimePolicy?: pulumi.Input<inputs.lambda.VersionRuntimePolicyArgs>;
}
