import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The ``AWS::Logs::MetricFilter`` resource specifies a metric filter that describes how CWL extracts information from logs and transforms it into Amazon CloudWatch metrics. If you have multiple metric filters that are associated with a log group, all the filters are applied to the log streams in that group.
 *  The maximum number of metric filters that can be associated with a log group is 100.
 */
export declare function getMetricFilter(args: GetMetricFilterArgs, opts?: pulumi.InvokeOptions): Promise<GetMetricFilterResult>;
export interface GetMetricFilterArgs {
    /**
     * The name of the metric filter.
     */
    filterName: string;
    /**
     * The name of an existing log group that you want to associate with this metric filter.
     */
    logGroupName: string;
}
export interface GetMetricFilterResult {
    /**
     * This parameter is valid only for log groups that have an active log transformer. For more information about log transformers, see [PutTransformer](https://docs.aws.amazon.com/AmazonCloudWatchLogs/latest/APIReference/API_PutTransformer.html).
     *  If this value is ``true``, the metric filter is applied on the transformed version of the log events instead of the original ingested log events.
     */
    readonly applyOnTransformedLogs?: boolean;
    /**
     * A filter pattern for extracting metric data out of ingested log events. For more information, see [Filter and Pattern Syntax](https://docs.aws.amazon.com/AmazonCloudWatch/latest/logs/FilterAndPatternSyntax.html).
     */
    readonly filterPattern?: string;
    /**
     * The metric transformations.
     */
    readonly metricTransformations?: outputs.logs.MetricFilterMetricTransformation[];
}
/**
 * The ``AWS::Logs::MetricFilter`` resource specifies a metric filter that describes how CWL extracts information from logs and transforms it into Amazon CloudWatch metrics. If you have multiple metric filters that are associated with a log group, all the filters are applied to the log streams in that group.
 *  The maximum number of metric filters that can be associated with a log group is 100.
 */
export declare function getMetricFilterOutput(args: GetMetricFilterOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetMetricFilterResult>;
export interface GetMetricFilterOutputArgs {
    /**
     * The name of the metric filter.
     */
    filterName: pulumi.Input<string>;
    /**
     * The name of an existing log group that you want to associate with this metric filter.
     */
    logGroupName: pulumi.Input<string>;
}
