import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::MediaConnect::Flow
 */
export declare function getFlow(args: GetFlowArgs, opts?: pulumi.InvokeOptions): Promise<GetFlowResult>;
export interface GetFlowArgs {
    /**
     * The Amazon Resource Name (ARN), a unique identifier for any AWS resource, of the flow.
     */
    flowArn: string;
}
export interface GetFlowResult {
    /**
     * The IP address from which video will be sent to output destinations.
     */
    readonly egressIp?: string;
    /**
     * The Amazon Resource Name (ARN), a unique identifier for any AWS resource, of the flow.
     */
    readonly flowArn?: string;
    /**
     * The Availability Zone that you want to create the flow in. These options are limited to the Availability Zones within the current AWS.(ReadOnly)
     */
    readonly flowAvailabilityZone?: string;
    /**
     * A prefix for the names of the NDI sources that the flow creates.(ReadOnly)
     */
    readonly flowNdiMachineName?: string;
    /**
     * Determines the processing capacity and feature set of the flow. Set this optional parameter to LARGE if you want to enable NDI outputs on the flow.
     */
    readonly flowSize?: enums.mediaconnect.FlowSize;
    /**
     * The maintenance settings you want to use for the flow.
     */
    readonly maintenance?: outputs.mediaconnect.FlowMaintenance;
    /**
     * The media streams associated with the flow. You can associate any of these media streams with sources and outputs on the flow.
     */
    readonly mediaStreams?: outputs.mediaconnect.FlowMediaStream[];
    /**
     * Specifies the configuration settings for NDI outputs. Required when the flow includes NDI outputs.
     */
    readonly ndiConfig?: outputs.mediaconnect.FlowNdiConfig;
    /**
     * The source of the flow.
     */
    readonly source?: outputs.mediaconnect.FlowSource;
    /**
     * The source failover config of the flow.
     */
    readonly sourceFailoverConfig?: outputs.mediaconnect.FlowFailoverConfig;
    /**
     * The source monitoring config of the flow.
     */
    readonly sourceMonitoringConfig?: outputs.mediaconnect.FlowSourceMonitoringConfig;
    /**
     * The VPC interfaces that you added to this flow.
     */
    readonly vpcInterfaces?: outputs.mediaconnect.FlowVpcInterface[];
}
/**
 * Resource schema for AWS::MediaConnect::Flow
 */
export declare function getFlowOutput(args: GetFlowOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetFlowResult>;
export interface GetFlowOutputArgs {
    /**
     * The Amazon Resource Name (ARN), a unique identifier for any AWS resource, of the flow.
     */
    flowArn: pulumi.Input<string>;
}
