import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * The AWS::MemoryDB::SubnetGroup resource creates an Amazon MemoryDB Subnet Group.
 */
export declare function getSubnetGroup(args: GetSubnetGroupArgs, opts?: pulumi.InvokeOptions): Promise<GetSubnetGroupResult>;
export interface GetSubnetGroupArgs {
    /**
     * The name of the subnet group. This value must be unique as it also serves as the subnet group identifier.
     */
    subnetGroupName: string;
}
export interface GetSubnetGroupResult {
    /**
     * The Amazon Resource Name (ARN) of the subnet group.
     */
    readonly arn?: string;
    /**
     * An optional description of the subnet group.
     */
    readonly description?: string;
    /**
     * A list of VPC subnet IDs for the subnet group.
     */
    readonly subnetIds?: string[];
    /**
     * Supported network types would be a list of network types supported by subnet group and can be either [ipv4] or [ipv4, dual_stack] or [ipv6].
     */
    readonly supportedNetworkTypes?: string[];
    /**
     * An array of key-value pairs to apply to this subnet group.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * The AWS::MemoryDB::SubnetGroup resource creates an Amazon MemoryDB Subnet Group.
 */
export declare function getSubnetGroupOutput(args: GetSubnetGroupOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetSubnetGroupResult>;
export interface GetSubnetGroupOutputArgs {
    /**
     * The name of the subnet group. This value must be unique as it also serves as the subnet group identifier.
     */
    subnetGroupName: pulumi.Input<string>;
}
