import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::MSK::VpcConnection
 */
export declare class VpcConnection extends pulumi.CustomResource {
    /**
     * Get an existing VpcConnection resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): VpcConnection;
    /**
     * Returns true if the given object is an instance of VpcConnection.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is VpcConnection;
    /**
     * The ARN of the VPC connection.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The type of private link authentication.
     */
    readonly authentication: pulumi.Output<enums.msk.VpcConnectionAuthentication>;
    /**
     * The list of subnets in the client VPC to connect to.
     */
    readonly clientSubnets: pulumi.Output<string[]>;
    /**
     * The security groups to attach to the ENIs for the broker nodes.
     */
    readonly securityGroups: pulumi.Output<string[]>;
    /**
     * An arbitrary set of tags (key-value pairs) you specify while creating the VPC connection.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * The Amazon Resource Name (ARN) of the target cluster
     */
    readonly targetClusterArn: pulumi.Output<string>;
    /**
     * The VPC ID of the remote client.
     */
    readonly vpcId: pulumi.Output<string>;
    /**
     * Create a VpcConnection resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: VpcConnectionArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a VpcConnection resource.
 */
export interface VpcConnectionArgs {
    /**
     * The type of private link authentication.
     */
    authentication: pulumi.Input<enums.msk.VpcConnectionAuthentication>;
    /**
     * The list of subnets in the client VPC to connect to.
     */
    clientSubnets: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The security groups to attach to the ENIs for the broker nodes.
     */
    securityGroups: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * An arbitrary set of tags (key-value pairs) you specify while creating the VPC connection.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
    /**
     * The Amazon Resource Name (ARN) of the target cluster
     */
    targetClusterArn: pulumi.Input<string>;
    /**
     * The VPC ID of the remote client.
     */
    vpcId: pulumi.Input<string>;
}
