import * as pulumi from "@pulumi/pulumi";
/**
 * The AWS::NetworkManager::TransitGatewayRegistration type registers a transit gateway in your global network. The transit gateway can be in any AWS Region, but it must be owned by the same AWS account that owns the global network. You cannot register a transit gateway in more than one global network.
 */
export declare class TransitGatewayRegistration extends pulumi.CustomResource {
    /**
     * Get an existing TransitGatewayRegistration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): TransitGatewayRegistration;
    /**
     * Returns true if the given object is an instance of TransitGatewayRegistration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is TransitGatewayRegistration;
    /**
     * The ID of the global network.
     */
    readonly globalNetworkId: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) of the transit gateway.
     */
    readonly transitGatewayArn: pulumi.Output<string>;
    /**
     * Create a TransitGatewayRegistration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: TransitGatewayRegistrationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a TransitGatewayRegistration resource.
 */
export interface TransitGatewayRegistrationArgs {
    /**
     * The ID of the global network.
     */
    globalNetworkId: pulumi.Input<string>;
    /**
     * The Amazon Resource Name (ARN) of the transit gateway.
     */
    transitGatewayArn: pulumi.Input<string>;
}
