import * as pulumi from "@pulumi/pulumi";
import * as enums from "../types/enums";
/**
 * Amazon OpenSearchServerless security policy resource
 */
export declare function getSecurityPolicy(args: GetSecurityPolicyArgs, opts?: pulumi.InvokeOptions): Promise<GetSecurityPolicyResult>;
export interface GetSecurityPolicyArgs {
    /**
     * The name of the policy
     */
    name: string;
    /**
     * The type of security policy. Can be either `encryption` or `network` .
     */
    type: enums.opensearchserverless.SecurityPolicyType;
}
export interface GetSecurityPolicyResult {
    /**
     * The description of the policy
     */
    readonly description?: string;
    /**
     * The JSON policy document that is the content for the policy
     */
    readonly policy?: string;
}
/**
 * Amazon OpenSearchServerless security policy resource
 */
export declare function getSecurityPolicyOutput(args: GetSecurityPolicyOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetSecurityPolicyResult>;
export interface GetSecurityPolicyOutputArgs {
    /**
     * The name of the policy
     */
    name: pulumi.Input<string>;
    /**
     * The type of security policy. Can be either `encryption` or `network` .
     */
    type: pulumi.Input<enums.opensearchserverless.SecurityPolicyType>;
}
