import * as pulumi from "@pulumi/pulumi";
/**
 * Definition of AWS::PCAConnectorAD::DirectoryRegistration Resource Type
 */
export declare class DirectoryRegistration extends pulumi.CustomResource {
    /**
     * Get an existing DirectoryRegistration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DirectoryRegistration;
    /**
     * Returns true if the given object is an instance of DirectoryRegistration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DirectoryRegistration;
    /**
     * The identifier of the Active Directory.
     */
    readonly directoryId: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) that was returned when you called [CreateDirectoryRegistration](https://docs.aws.amazon.com/pca-connector-ad/latest/APIReference/API_CreateDirectoryRegistration.html) .
     */
    readonly directoryRegistrationArn: pulumi.Output<string>;
    /**
     * Metadata assigned to a directory registration consisting of a key-value pair.
     */
    readonly tags: pulumi.Output<{
        [key: string]: string;
    } | undefined>;
    /**
     * Create a DirectoryRegistration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DirectoryRegistrationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DirectoryRegistration resource.
 */
export interface DirectoryRegistrationArgs {
    /**
     * The identifier of the Active Directory.
     */
    directoryId: pulumi.Input<string>;
    /**
     * Metadata assigned to a directory registration consisting of a key-value pair.
     */
    tags?: pulumi.Input<{
        [key: string]: pulumi.Input<string>;
    }>;
}
