import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of AWS::QBusiness::Index Resource Type
 */
export declare function getIndex(args: GetIndexArgs, opts?: pulumi.InvokeOptions): Promise<GetIndexResult>;
export interface GetIndexArgs {
    /**
     * The identifier of the Amazon Q Business application using the index.
     */
    applicationId: string;
    /**
     * The identifier for the index.
     */
    indexId: string;
}
export interface GetIndexResult {
    /**
     * The capacity units you want to provision for your index. You can add and remove capacity to fit your usage needs.
     */
    readonly capacityConfiguration?: outputs.qbusiness.IndexCapacityConfiguration;
    /**
     * The Unix timestamp when the index was created.
     */
    readonly createdAt?: string;
    /**
     * A description for the Amazon Q Business index.
     */
    readonly description?: string;
    /**
     * The name of the index.
     */
    readonly displayName?: string;
    /**
     * Configuration information for document attributes. Document attributes are metadata or fields associated with your documents. For example, the company department name associated with each document.
     *
     * For more information, see [Understanding document attributes](https://docs.aws.amazon.com/amazonq/latest/business-use-dg/doc-attributes.html) .
     */
    readonly documentAttributeConfigurations?: outputs.qbusiness.IndexDocumentAttributeConfiguration[];
    /**
     * The Amazon Resource Name (ARN) of an Amazon Q Business index.
     */
    readonly indexArn?: string;
    /**
     * The identifier for the index.
     */
    readonly indexId?: string;
    readonly indexStatistics?: outputs.qbusiness.IndexStatistics;
    /**
     * The current status of the index. When the status is `ACTIVE` , the index is ready.
     */
    readonly status?: enums.qbusiness.IndexStatus;
    /**
     * A list of key-value pairs that identify or categorize the index. You can also use tags to help control access to the index. Tag keys and values can consist of Unicode letters, digits, white space, and any of the following symbols: _ . : / = + - @.
     */
    readonly tags?: outputs.Tag[];
    /**
     * The Unix timestamp when the index was last updated.
     */
    readonly updatedAt?: string;
}
/**
 * Definition of AWS::QBusiness::Index Resource Type
 */
export declare function getIndexOutput(args: GetIndexOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetIndexResult>;
export interface GetIndexOutputArgs {
    /**
     * The identifier of the Amazon Q Business application using the index.
     */
    applicationId: pulumi.Input<string>;
    /**
     * The identifier for the index.
     */
    indexId: pulumi.Input<string>;
}
