import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of the AWS::QuickSight::CustomPermissions Resource Type.
 */
export declare class CustomPermissions extends pulumi.CustomResource {
    /**
     * Get an existing CustomPermissions resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): CustomPermissions;
    /**
     * Returns true if the given object is an instance of CustomPermissions.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is CustomPermissions;
    /**
     * The Amazon Resource Name (ARN) of the custom permissions profile.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the AWS account that contains the custom permission configuration that you want to update.
     */
    readonly awsAccountId: pulumi.Output<string>;
    /**
     * A set of actions in the custom permissions profile.
     */
    readonly capabilities: pulumi.Output<outputs.quicksight.CustomPermissionsCapabilities | undefined>;
    /**
     * The name of the custom permissions profile.
     */
    readonly customPermissionsName: pulumi.Output<string>;
    /**
     * The tags to associate with the custom permissions profile.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a CustomPermissions resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: CustomPermissionsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a CustomPermissions resource.
 */
export interface CustomPermissionsArgs {
    /**
     * The ID of the AWS account that contains the custom permission configuration that you want to update.
     */
    awsAccountId: pulumi.Input<string>;
    /**
     * A set of actions in the custom permissions profile.
     */
    capabilities?: pulumi.Input<inputs.quicksight.CustomPermissionsCapabilitiesArgs>;
    /**
     * The name of the custom permissions profile.
     */
    customPermissionsName?: pulumi.Input<string>;
    /**
     * The tags to associate with the custom permissions profile.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
