import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Definition of the AWS::QuickSight::Topic Resource Type.
 */
export declare function getTopic(args: GetTopicArgs, opts?: pulumi.InvokeOptions): Promise<GetTopicResult>;
export interface GetTopicArgs {
    /**
     * The ID of the AWS account that you want to create a topic in.
     */
    awsAccountId: string;
    /**
     * The ID for the topic. This ID is unique per AWS Region for each AWS account.
     */
    topicId: string;
}
export interface GetTopicResult {
    /**
     * The Amazon Resource Name (ARN) of the topic.
     */
    readonly arn?: string;
    /**
     * Configuration options for a `Topic` .
     */
    readonly configOptions?: outputs.quicksight.TopicConfigOptions;
    /**
     * The data sets that the topic is associated with.
     */
    readonly dataSets?: outputs.quicksight.TopicDatasetMetadata[];
    /**
     * The description of the topic.
     */
    readonly description?: string;
    /**
     * The name of the topic.
     */
    readonly name?: string;
    /**
     * The user experience version of the topic.
     */
    readonly userExperienceVersion?: enums.quicksight.TopicUserExperienceVersion;
}
/**
 * Definition of the AWS::QuickSight::Topic Resource Type.
 */
export declare function getTopicOutput(args: GetTopicOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetTopicResult>;
export interface GetTopicOutputArgs {
    /**
     * The ID of the AWS account that you want to create a topic in.
     */
    awsAccountId: pulumi.Input<string>;
    /**
     * The ID for the topic. This ID is unique per AWS Region for each AWS account.
     */
    topicId: pulumi.Input<string>;
}
