import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of the AWS::QuickSight::RefreshSchedule Resource Type.
 */
export declare class RefreshSchedule extends pulumi.CustomResource {
    /**
     * Get an existing RefreshSchedule resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): RefreshSchedule;
    /**
     * Returns true if the given object is an instance of RefreshSchedule.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is RefreshSchedule;
    /**
     * <p>The Amazon Resource Name (ARN) of the data source.</p>
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The AWS account ID of the account that you are creating a schedule in.
     */
    readonly awsAccountId: pulumi.Output<string | undefined>;
    /**
     * The ID of the dataset that you are creating a refresh schedule for.
     */
    readonly dataSetId: pulumi.Output<string | undefined>;
    /**
     * The refresh schedule of a dataset.
     */
    readonly schedule: pulumi.Output<outputs.quicksight.RefreshScheduleMap | undefined>;
    /**
     * Create a RefreshSchedule resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: RefreshScheduleArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a RefreshSchedule resource.
 */
export interface RefreshScheduleArgs {
    /**
     * The AWS account ID of the account that you are creating a schedule in.
     */
    awsAccountId?: pulumi.Input<string>;
    /**
     * The ID of the dataset that you are creating a refresh schedule for.
     */
    dataSetId?: pulumi.Input<string>;
    /**
     * The refresh schedule of a dataset.
     */
    schedule?: pulumi.Input<inputs.quicksight.RefreshScheduleMapArgs>;
}
