import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource schema for AWS::RDS::DBProxyTargetGroup
 */
export declare class DbProxyTargetGroup extends pulumi.CustomResource {
    /**
     * Get an existing DbProxyTargetGroup resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): DbProxyTargetGroup;
    /**
     * Returns true if the given object is an instance of DbProxyTargetGroup.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is DbProxyTargetGroup;
    /**
     * Displays the settings that control the size and behavior of the connection pool associated with a `DBProxyTarget` .
     */
    readonly connectionPoolConfigurationInfo: pulumi.Output<outputs.rds.DbProxyTargetGroupConnectionPoolConfigurationInfoFormat | undefined>;
    /**
     * One or more DB cluster identifiers.
     */
    readonly dbClusterIdentifiers: pulumi.Output<string[] | undefined>;
    /**
     * One or more DB instance identifiers.
     */
    readonly dbInstanceIdentifiers: pulumi.Output<string[] | undefined>;
    /**
     * The identifier for the proxy.
     */
    readonly dbProxyName: pulumi.Output<string>;
    /**
     * The Amazon Resource Name (ARN) representing the target group.
     */
    readonly targetGroupArn: pulumi.Output<string>;
    /**
     * The identifier for the DBProxyTargetGroup
     */
    readonly targetGroupName: pulumi.Output<enums.rds.DbProxyTargetGroupTargetGroupName>;
    /**
     * Create a DbProxyTargetGroup resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: DbProxyTargetGroupArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a DbProxyTargetGroup resource.
 */
export interface DbProxyTargetGroupArgs {
    /**
     * Displays the settings that control the size and behavior of the connection pool associated with a `DBProxyTarget` .
     */
    connectionPoolConfigurationInfo?: pulumi.Input<inputs.rds.DbProxyTargetGroupConnectionPoolConfigurationInfoFormatArgs>;
    /**
     * One or more DB cluster identifiers.
     */
    dbClusterIdentifiers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * One or more DB instance identifiers.
     */
    dbInstanceIdentifiers?: pulumi.Input<pulumi.Input<string>[]>;
    /**
     * The identifier for the proxy.
     */
    dbProxyName: pulumi.Input<string>;
    /**
     * The identifier for the DBProxyTargetGroup
     */
    targetGroupName: pulumi.Input<enums.rds.DbProxyTargetGroupTargetGroupName>;
}
