import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::SageMaker::Domain
 */
export declare function getDomain(args: GetDomainArgs, opts?: pulumi.InvokeOptions): Promise<GetDomainResult>;
export interface GetDomainArgs {
    /**
     * The domain name.
     */
    domainId: string;
}
export interface GetDomainResult {
    /**
     * Specifies the VPC used for non-EFS traffic. The default value is PublicInternetOnly.
     */
    readonly appNetworkAccessType?: enums.sagemaker.DomainAppNetworkAccessType;
    /**
     * The entity that creates and manages the required security groups for inter-app communication in VPCOnly mode. Required when CreateDomain.AppNetworkAccessType is VPCOnly and DomainSettings.RStudioServerProDomainSettings.DomainExecutionRoleArn is provided.
     */
    readonly appSecurityGroupManagement?: enums.sagemaker.DomainAppSecurityGroupManagement;
    /**
     * The default space settings.
     */
    readonly defaultSpaceSettings?: outputs.sagemaker.DomainDefaultSpaceSettings;
    /**
     * The default user settings.
     */
    readonly defaultUserSettings?: outputs.sagemaker.DomainUserSettings;
    /**
     * The Amazon Resource Name (ARN) of the created domain.
     */
    readonly domainArn?: string;
    /**
     * The domain name.
     */
    readonly domainId?: string;
    /**
     * A collection of settings that apply to the `SageMaker Domain` . These settings are specified through the `CreateDomain` API call.
     */
    readonly domainSettings?: outputs.sagemaker.DomainSettings;
    /**
     * The ID of the Amazon Elastic File System (EFS) managed by this Domain.
     */
    readonly homeEfsFileSystemId?: string;
    /**
     * The ID of the security group that authorizes traffic between the RSessionGateway apps and the RStudioServerPro app.
     */
    readonly securityGroupIdForDomainBoundary?: string;
    /**
     * The ARN of the application managed by SageMaker in IAM Identity Center. This value is only returned for domains created after October 1, 2023.
     */
    readonly singleSignOnApplicationArn?: string;
    /**
     * The SSO managed application instance ID.
     */
    readonly singleSignOnManagedApplicationInstanceId?: string;
    /**
     * The VPC subnets that Studio uses for communication.
     */
    readonly subnetIds?: string[];
    /**
     * Indicates whether the tags added to Domain, User Profile and Space entity is propagated to all SageMaker resources.
     */
    readonly tagPropagation?: enums.sagemaker.DomainTagPropagation;
    /**
     * The URL to the created domain.
     */
    readonly url?: string;
}
/**
 * Resource Type definition for AWS::SageMaker::Domain
 */
export declare function getDomainOutput(args: GetDomainOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetDomainResult>;
export interface GetDomainOutputArgs {
    /**
     * The domain name.
     */
    domainId: pulumi.Input<string>;
}
