import * as pulumi from "@pulumi/pulumi";
/**
 * Resource Type definition for AWS::SecretsManager::ResourcePolicy
 */
export declare class ResourcePolicy extends pulumi.CustomResource {
    /**
     * Get an existing ResourcePolicy resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ResourcePolicy;
    /**
     * Returns true if the given object is an instance of ResourcePolicy.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ResourcePolicy;
    /**
     * The Arn of the secret.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * Specifies whether to block resource-based policies that allow broad access to the secret.
     */
    readonly blockPublicPolicy: pulumi.Output<boolean | undefined>;
    /**
     * A JSON-formatted string for an AWS resource-based policy.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::SecretsManager::ResourcePolicy` for more information about the expected schema for this property.
     */
    readonly resourcePolicy: pulumi.Output<any>;
    /**
     * The ARN or name of the secret to attach the resource-based policy.
     */
    readonly secretId: pulumi.Output<string>;
    /**
     * Create a ResourcePolicy resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: ResourcePolicyArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ResourcePolicy resource.
 */
export interface ResourcePolicyArgs {
    /**
     * Specifies whether to block resource-based policies that allow broad access to the secret.
     */
    blockPublicPolicy?: pulumi.Input<boolean>;
    /**
     * A JSON-formatted string for an AWS resource-based policy.
     *
     * Search the [CloudFormation User Guide](https://docs.aws.amazon.com/cloudformation/) for `AWS::SecretsManager::ResourcePolicy` for more information about the expected schema for this property.
     */
    resourcePolicy: any;
    /**
     * The ARN or name of the secret to attach the resource-based policy.
     */
    secretId: pulumi.Input<string>;
}
