import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for AWS::SES::EmailIdentity
 */
export declare class EmailIdentity extends pulumi.CustomResource {
    /**
     * Get an existing EmailIdentity resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): EmailIdentity;
    /**
     * Returns true if the given object is an instance of EmailIdentity.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is EmailIdentity;
    /**
     * Used to associate a configuration set with an email identity.
     */
    readonly configurationSetAttributes: pulumi.Output<outputs.ses.EmailIdentityConfigurationSetAttributes | undefined>;
    /**
     * An object that contains information about the DKIM attributes for the identity.
     */
    readonly dkimAttributes: pulumi.Output<outputs.ses.EmailIdentityDkimAttributes | undefined>;
    /**
     * The host name for the first token that you have to add to the DNS configuration for your domain.
     */
    readonly dkimDnsTokenName1: pulumi.Output<string>;
    /**
     * The host name for the second token that you have to add to the DNS configuration for your domain.
     */
    readonly dkimDnsTokenName2: pulumi.Output<string>;
    /**
     * The host name for the third token that you have to add to the DNS configuration for your domain.
     */
    readonly dkimDnsTokenName3: pulumi.Output<string>;
    /**
     * The record value for the first token that you have to add to the DNS configuration for your domain.
     */
    readonly dkimDnsTokenValue1: pulumi.Output<string>;
    /**
     * The record value for the second token that you have to add to the DNS configuration for your domain.
     */
    readonly dkimDnsTokenValue2: pulumi.Output<string>;
    /**
     * The record value for the third token that you have to add to the DNS configuration for your domain.
     */
    readonly dkimDnsTokenValue3: pulumi.Output<string>;
    /**
     * If your request includes this object, Amazon SES configures the identity to use Bring Your Own DKIM (BYODKIM) for DKIM authentication purposes, or, configures the key length to be used for [Easy DKIM](https://docs.aws.amazon.com/ses/latest/DeveloperGuide/easy-dkim.html) .
     *
     * You can only specify this object if the email identity is a domain, as opposed to an address.
     */
    readonly dkimSigningAttributes: pulumi.Output<outputs.ses.EmailIdentityDkimSigningAttributes | undefined>;
    /**
     * The email address or domain to verify.
     */
    readonly emailIdentity: pulumi.Output<string>;
    /**
     * Used to enable or disable feedback forwarding for an identity.
     */
    readonly feedbackAttributes: pulumi.Output<outputs.ses.EmailIdentityFeedbackAttributes | undefined>;
    /**
     * Used to enable or disable the custom Mail-From domain configuration for an email identity.
     */
    readonly mailFromAttributes: pulumi.Output<outputs.ses.EmailIdentityMailFromAttributes | undefined>;
    /**
     * Create a EmailIdentity resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: EmailIdentityArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a EmailIdentity resource.
 */
export interface EmailIdentityArgs {
    /**
     * Used to associate a configuration set with an email identity.
     */
    configurationSetAttributes?: pulumi.Input<inputs.ses.EmailIdentityConfigurationSetAttributesArgs>;
    /**
     * An object that contains information about the DKIM attributes for the identity.
     */
    dkimAttributes?: pulumi.Input<inputs.ses.EmailIdentityDkimAttributesArgs>;
    /**
     * If your request includes this object, Amazon SES configures the identity to use Bring Your Own DKIM (BYODKIM) for DKIM authentication purposes, or, configures the key length to be used for [Easy DKIM](https://docs.aws.amazon.com/ses/latest/DeveloperGuide/easy-dkim.html) .
     *
     * You can only specify this object if the email identity is a domain, as opposed to an address.
     */
    dkimSigningAttributes?: pulumi.Input<inputs.ses.EmailIdentityDkimSigningAttributesArgs>;
    /**
     * The email address or domain to verify.
     */
    emailIdentity: pulumi.Input<string>;
    /**
     * Used to enable or disable feedback forwarding for an identity.
     */
    feedbackAttributes?: pulumi.Input<inputs.ses.EmailIdentityFeedbackAttributesArgs>;
    /**
     * Used to enable or disable the custom Mail-From domain configuration for an email identity.
     */
    mailFromAttributes?: pulumi.Input<inputs.ses.EmailIdentityMailFromAttributesArgs>;
}
