import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::SES::MailManagerAddonInstance Resource Type
 */
export declare class MailManagerAddonInstance extends pulumi.CustomResource {
    /**
     * Get an existing MailManagerAddonInstance resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): MailManagerAddonInstance;
    /**
     * Returns true if the given object is an instance of MailManagerAddonInstance.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is MailManagerAddonInstance;
    /**
     * The Amazon Resource Name (ARN) of the Add On instance.
     */
    readonly addonInstanceArn: pulumi.Output<string>;
    /**
     * The unique ID of the Add On instance.
     */
    readonly addonInstanceId: pulumi.Output<string>;
    /**
     * The name of the Add On for the instance.
     */
    readonly addonName: pulumi.Output<string>;
    /**
     * The subscription ID for the instance.
     */
    readonly addonSubscriptionId: pulumi.Output<string>;
    /**
     * The tags used to organize, track, or control access for the resource. For example, { "tags": {"key1":"value1", "key2":"value2"} }.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a MailManagerAddonInstance resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: MailManagerAddonInstanceArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a MailManagerAddonInstance resource.
 */
export interface MailManagerAddonInstanceArgs {
    /**
     * The subscription ID for the instance.
     */
    addonSubscriptionId: pulumi.Input<string>;
    /**
     * The tags used to organize, track, or control access for the resource. For example, { "tags": {"key1":"value1", "key2":"value2"} }.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
