import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Resource Type definition for SSO InstanceAccessControlAttributeConfiguration
 *
 * ## Example Usage
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const abac = new aws_native.sso.InstanceAccessControlAttributeConfiguration("abac", {
 *     instanceArn: "arn:aws:sso:::instance/ssoins-instanceId",
 *     accessControlAttributes: [{
 *         key: "CostCenter",
 *         value: {
 *             source: ["${path:enterprise.costCenter}"],
 *         },
 *     }],
 * });
 *
 * ```
 * ### Example
 *
 * ```typescript
 * import * as pulumi from "@pulumi/pulumi";
 * import * as aws_native from "@pulumi/aws-native";
 *
 * const abac = new aws_native.sso.InstanceAccessControlAttributeConfiguration("abac", {
 *     instanceArn: "arn:aws:sso:::instance/ssoins-instanceId",
 *     accessControlAttributes: [{
 *         key: "CostCenter",
 *         value: {
 *             source: ["${path:enterprise.costCenter}"],
 *         },
 *     }],
 * });
 *
 * ```
 */
export declare class InstanceAccessControlAttributeConfiguration extends pulumi.CustomResource {
    /**
     * Get an existing InstanceAccessControlAttributeConfiguration resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): InstanceAccessControlAttributeConfiguration;
    /**
     * Returns true if the given object is an instance of InstanceAccessControlAttributeConfiguration.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is InstanceAccessControlAttributeConfiguration;
    /**
     * Lists the attributes that are configured for ABAC in the specified IAM Identity Center instance.
     */
    readonly accessControlAttributes: pulumi.Output<outputs.sso.InstanceAccessControlAttributeConfigurationAccessControlAttribute[] | undefined>;
    /**
     * The InstanceAccessControlAttributeConfiguration property has been deprecated but is still supported for backwards compatibility purposes. We recomend that you use  AccessControlAttributes property instead.
     */
    readonly instanceAccessControlAttributeConfiguration: pulumi.Output<outputs.sso.InstanceAccessControlAttributeConfigurationProperties | undefined>;
    /**
     * The ARN of the AWS SSO instance under which the operation will be executed.
     */
    readonly instanceArn: pulumi.Output<string>;
    /**
     * Create a InstanceAccessControlAttributeConfiguration resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: InstanceAccessControlAttributeConfigurationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a InstanceAccessControlAttributeConfiguration resource.
 */
export interface InstanceAccessControlAttributeConfigurationArgs {
    /**
     * Lists the attributes that are configured for ABAC in the specified IAM Identity Center instance.
     */
    accessControlAttributes?: pulumi.Input<pulumi.Input<inputs.sso.InstanceAccessControlAttributeConfigurationAccessControlAttributeArgs>[]>;
    /**
     * The InstanceAccessControlAttributeConfiguration property has been deprecated but is still supported for backwards compatibility purposes. We recomend that you use  AccessControlAttributes property instead.
     */
    instanceAccessControlAttributeConfiguration?: pulumi.Input<inputs.sso.InstanceAccessControlAttributeConfigurationPropertiesArgs>;
    /**
     * The ARN of the AWS SSO instance under which the operation will be executed.
     */
    instanceArn: pulumi.Input<string>;
}
