import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Resource schema for StateMachineAlias
 */
export declare function getStateMachineAlias(args: GetStateMachineAliasArgs, opts?: pulumi.InvokeOptions): Promise<GetStateMachineAliasResult>;
export interface GetStateMachineAliasArgs {
    /**
     * The ARN of the alias.
     */
    arn: string;
}
export interface GetStateMachineAliasResult {
    /**
     * The ARN of the alias.
     */
    readonly arn?: string;
    /**
     * An optional description of the alias.
     */
    readonly description?: string;
    /**
     * The routing configuration of an alias. Routing configuration splits [StartExecution](https://docs.aws.amazon.com/step-functions/latest/apireference/API_StartExecution.html) requests between one or two versions of the same state machine.
     *
     * Use `RoutingConfiguration` if you want to explicitly set the alias [weights](https://docs.aws.amazon.com/step-functions/latest/apireference/API_RoutingConfigurationListItem.html#StepFunctions-Type-RoutingConfigurationListItem-weight) . Weight is the percentage of traffic you want to route to a state machine version.
     *
     * > `RoutingConfiguration` and `DeploymentPreference` are mutually exclusive properties. You must define only one of these properties.
     */
    readonly routingConfiguration?: outputs.stepfunctions.StateMachineAliasRoutingConfigurationVersion[];
}
/**
 * Resource schema for StateMachineAlias
 */
export declare function getStateMachineAliasOutput(args: GetStateMachineAliasOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetStateMachineAliasResult>;
export interface GetStateMachineAliasOutputArgs {
    /**
     * The ARN of the alias.
     */
    arn: pulumi.Input<string>;
}
