import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
import * as enums from "../types/enums";
/**
 * Resource Type definition for AWS::Transfer::Agreement
 */
export declare function getAgreement(args: GetAgreementArgs, opts?: pulumi.InvokeOptions): Promise<GetAgreementResult>;
export interface GetAgreementArgs {
    /**
     * A unique identifier for the agreement.
     */
    agreementId: string;
    /**
     * A unique identifier for the server.
     */
    serverId: string;
}
export interface GetAgreementResult {
    /**
     * Specifies the access role for the agreement.
     */
    readonly accessRole?: string;
    /**
     * A unique identifier for the agreement.
     */
    readonly agreementId?: string;
    /**
     * Specifies the unique Amazon Resource Name (ARN) for the agreement.
     */
    readonly arn?: string;
    /**
     * Specifies the base directory for the agreement.
     */
    readonly baseDirectory?: string;
    /**
     * Specifies a separate directory for each type of file to store for an AS2 message.
     */
    readonly customDirectories?: outputs.transfer.CustomDirectoriesProperties;
    /**
     * A textual description for the agreement.
     */
    readonly description?: string;
    /**
     * Specifies whether to enforce an AS2 message is signed for this agreement.
     */
    readonly enforceMessageSigning?: enums.transfer.AgreementEnforceMessageSigning;
    /**
     * A unique identifier for the local profile.
     */
    readonly localProfileId?: string;
    /**
     * A unique identifier for the partner profile.
     */
    readonly partnerProfileId?: string;
    /**
     * Specifies whether to preserve the filename received for this agreement.
     */
    readonly preserveFilename?: enums.transfer.AgreementPreserveFilename;
    /**
     * Specifies the status of the agreement.
     */
    readonly status?: enums.transfer.AgreementStatus;
    /**
     * Key-value pairs that can be used to group and search for agreements. Tags are metadata attached to agreements for any purpose.
     */
    readonly tags?: outputs.Tag[];
}
/**
 * Resource Type definition for AWS::Transfer::Agreement
 */
export declare function getAgreementOutput(args: GetAgreementOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAgreementResult>;
export interface GetAgreementOutputArgs {
    /**
     * A unique identifier for the agreement.
     */
    agreementId: pulumi.Input<string>;
    /**
     * A unique identifier for the server.
     */
    serverId: pulumi.Input<string>;
}
