import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * VpcLattice ServiceNetworkResourceAssociation CFN resource
 */
export declare class ServiceNetworkResourceAssociation extends pulumi.CustomResource {
    /**
     * Get an existing ServiceNetworkResourceAssociation resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): ServiceNetworkResourceAssociation;
    /**
     * Returns true if the given object is an instance of ServiceNetworkResourceAssociation.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is ServiceNetworkResourceAssociation;
    /**
     * The Amazon Resource Name (ARN) of the association.
     */
    readonly arn: pulumi.Output<string>;
    /**
     * The ID of the association between the service network and resource configuration.
     */
    readonly awsId: pulumi.Output<string>;
    /**
     * The ID of the resource configuration associated with the service network.
     */
    readonly resourceConfigurationId: pulumi.Output<string | undefined>;
    /**
     * The ID of the service network associated with the resource configuration.
     */
    readonly serviceNetworkId: pulumi.Output<string | undefined>;
    /**
     * A key-value pair to associate with a resource.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * Create a ServiceNetworkResourceAssociation resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args?: ServiceNetworkResourceAssociationArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a ServiceNetworkResourceAssociation resource.
 */
export interface ServiceNetworkResourceAssociationArgs {
    /**
     * The ID of the resource configuration associated with the service network.
     */
    resourceConfigurationId?: pulumi.Input<string>;
    /**
     * The ID of the service network associated with the resource configuration.
     */
    serviceNetworkId?: pulumi.Input<string>;
    /**
     * A key-value pair to associate with a resource.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
