import * as pulumi from "@pulumi/pulumi";
import * as outputs from "../types/output";
/**
 * Definition of AWS::Wisdom::AIAgent Resource Type
 */
export declare function getAiAgent(args: GetAiAgentArgs, opts?: pulumi.InvokeOptions): Promise<GetAiAgentResult>;
export interface GetAiAgentArgs {
    /**
     * The identifier of the AI Agent.
     */
    aiAgentId: string;
    /**
     * The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.
     */
    assistantId: string;
}
export interface GetAiAgentResult {
    /**
     * The Amazon Resource Name (ARN) of the AI agent.
     */
    readonly aiAgentArn?: string;
    /**
     * The identifier of the AI Agent.
     */
    readonly aiAgentId?: string;
    /**
     * The Amazon Resource Name (ARN) of the Amazon Q in Connect assistant.
     */
    readonly assistantArn?: string;
    /**
     * Configuration for the AI Agent.
     */
    readonly configuration?: outputs.wisdom.AiAgentAiAgentConfiguration0Properties | outputs.wisdom.AiAgentAiAgentConfiguration1Properties | outputs.wisdom.AiAgentAiAgentConfiguration2Properties;
    /**
     * The description of the AI Agent.
     */
    readonly description?: string;
    readonly modifiedTimeSeconds?: number;
}
/**
 * Definition of AWS::Wisdom::AIAgent Resource Type
 */
export declare function getAiAgentOutput(args: GetAiAgentOutputArgs, opts?: pulumi.InvokeOutputOptions): pulumi.Output<GetAiAgentResult>;
export interface GetAiAgentOutputArgs {
    /**
     * The identifier of the AI Agent.
     */
    aiAgentId: pulumi.Input<string>;
    /**
     * The identifier of the Amazon Q in Connect assistant. Can be either the ID or the ARN. URLs cannot contain the ARN.
     */
    assistantId: pulumi.Input<string>;
}
