import * as pulumi from "@pulumi/pulumi";
import * as inputs from "../types/input";
import * as outputs from "../types/output";
/**
 * Definition of AWS::WorkSpacesWeb::UserAccessLoggingSettings Resource Type
 */
export declare class UserAccessLoggingSettings extends pulumi.CustomResource {
    /**
     * Get an existing UserAccessLoggingSettings resource's state with the given name, ID, and optional extra
     * properties used to qualify the lookup.
     *
     * @param name The _unique_ name of the resulting resource.
     * @param id The _unique_ provider ID of the resource to lookup.
     * @param opts Optional settings to control the behavior of the CustomResource.
     */
    static get(name: string, id: pulumi.Input<pulumi.ID>, opts?: pulumi.CustomResourceOptions): UserAccessLoggingSettings;
    /**
     * Returns true if the given object is an instance of UserAccessLoggingSettings.  This is designed to work even
     * when multiple copies of the Pulumi SDK have been loaded into the same process.
     */
    static isInstance(obj: any): obj is UserAccessLoggingSettings;
    /**
     * A list of web portal ARNs that this user access logging settings is associated with.
     */
    readonly associatedPortalArns: pulumi.Output<string[]>;
    /**
     * Kinesis stream ARN to which log events are published.
     */
    readonly kinesisStreamArn: pulumi.Output<string>;
    /**
     * The tags to add to the user access logging settings resource. A tag is a key-value pair.
     */
    readonly tags: pulumi.Output<outputs.Tag[] | undefined>;
    /**
     * The ARN of the user access logging settings.
     */
    readonly userAccessLoggingSettingsArn: pulumi.Output<string>;
    /**
     * Create a UserAccessLoggingSettings resource with the given unique name, arguments, and options.
     *
     * @param name The _unique_ name of the resource.
     * @param args The arguments to use to populate this resource's properties.
     * @param opts A bag of options that control this resource's behavior.
     */
    constructor(name: string, args: UserAccessLoggingSettingsArgs, opts?: pulumi.CustomResourceOptions);
}
/**
 * The set of arguments for constructing a UserAccessLoggingSettings resource.
 */
export interface UserAccessLoggingSettingsArgs {
    /**
     * Kinesis stream ARN to which log events are published.
     */
    kinesisStreamArn: pulumi.Input<string>;
    /**
     * The tags to add to the user access logging settings resource. A tag is a key-value pair.
     */
    tags?: pulumi.Input<pulumi.Input<inputs.TagArgs>[]>;
}
